=======
History
=======

0.1.0 (2018-01-05)
------------------

* First release on PyPI.

0.2.0 (2018-04-11)
------------------

* Recipes were added in
* Custom Checkers
* Multiple master files can be used
* Module associated files to find master configs
* Detail finding in cli to get help on the fly

0.3.0 (2018-08-10)
------------------

* Added the ability require an config entry be a list
* Added significant unit tests

0.4.0 (2019-07-19)
------------------

* Added in url datatype
* Added Datetime Ordered data type for start stop options
* Added in an inidiff script for comparing config files

0.5.0 (2019-08-22)
------------------

* Fixed bug relating to Datetime Ordered Pairs
* Added in inimake script for creating scripts from scratch
* Added in more unittests (54% coverage)


0.6.0 (2019-10-16)
------------------

* Built in a brand new feature for migrating large changes in configs
* Added bounds checking for type checking allowing for continuous types
* Fixes for issues: 25_ , 27_ , 31_ , 32_

.. _25: https://github.com/USDA-ARS-NWRC/inicheck/issues/25
.. _27: https://github.com/USDA-ARS-NWRC/inicheck/issues/27
.. _31: https://github.com/USDA-ARS-NWRC/inicheck/issues/31
.. _32: https://github.com/USDA-ARS-NWRC/inicheck/issues/32


0.7.0 (2019-10-22)
------------------
* Restructure the checkers some to better handle types
* Fixed several broken tests.

0.8.0 (05-29-2020)
------------------
* Increased unittest coverage from ~57% to ~83%)
* Added in a CLI tool to find changelog impacts in python files
* Switch from pandas to_datetime to dateparser to reduce package size
* Added inicheck to traviCI and Coveralls
* Fixes for 35_ , 38_ , 39_, 40_, 41_, 42_ 43_, 44_, 45_
* Added in linting with isort and autopep8
* Hardcoded `parse_date` to always use UTC and return timezone unaware object. 51_
* Updated release to use setuptools_scm. 52_ 

.. _35: https://github.com/USDA-ARS-NWRC/inicheck/issues/25
.. _38: https://github.com/USDA-ARS-NWRC/inicheck/issues/27
.. _39: https://github.com/USDA-ARS-NWRC/inicheck/issues/31
.. _40: https://github.com/USDA-ARS-NWRC/inicheck/issues/40
.. _41: https://github.com/USDA-ARS-NWRC/inicheck/issues/41
.. _42: https://github.com/USDA-ARS-NWRC/inicheck/pull/42
.. _43: https://github.com/USDA-ARS-NWRC/inicheck/issues/43
.. _44: https://github.com/USDA-ARS-NWRC/inicheck/issues/44
.. _45: https://github.com/USDA-ARS-NWRC/inicheck/issues/45
.. _51: https://github.com/USDA-ARS-NWRC/inicheck/issues/51
.. _52: https://github.com/USDA-ARS-NWRC/inicheck/pull/52
